==> ra-sdk-1.0.4.1-20200603.064959-2-sources.jar: com/xdja/ra/bean/FreezeApplyInfo.java <==
package com.xdja.ra.bean;

/**
 * 冻结/解冻申请详情
 *
 * @author yangmenghao
 * @date 2020-03-24 10:30:58
 */
public class FreezeApplyInfo {
    /**
     * 必须	申请原因
     */
    private String applyReason;
    /**
     * 必须	申请状态 1:待审核  2:审核未通过  3:待签发  4:签发未通过  5:已签发  6:撤销失败   7:已撤销  8:冻结失败 9:已冻结  10:解冻失败  11:已解冻
     */
    private Integer applyStatus;
    /**
     * 必须	待冻结/解冻证书DN
     */
    private String certDn;
    /**
     * 必须	待冻结/解冻证书的加密证书SN
     */
    private String encSn;
    /**
     * 必须	申请创建时间
     */
    private String gmtCreate;
    /**
     * 必须	待冻结/解冻证书的签名证书SN
     */
    private String signSn;
    /**
     * 必填	模板名称
     */
    private String tempName;
    /**
     * 必填	模板编号
     */
    private String tempNo;
    /**
     * 必填	模板要求参数
     */
    private String tempParas;

    public String getApplyReason() {
        return applyReason;
    }

    public void setApplyReason(String applyReason) {
        this.applyReason = applyReason;
    }

    public Integer getApplyStatus() {
        return applyStatus;
    }

    public void setApplyStatus(Integer applyStatus) {
        this.applyStatus = applyStatus;
    }

    public String getCertDn() {
        return certDn;
    }

    public void setCertDn(String certDn) {
        this.certDn = certDn;
    }

    public String getEncSn() {
        return encSn;
    }

    public void setEncSn(String encSn) {
        this.encSn = encSn;
    }

    public String getGmtCreate() {
        return gmtCreate;
    }

    public void setGmtCreate(String gmtCreate) {
        this.gmtCreate = gmtCreate;
    }

    public String getSignSn() {
        return signSn;
    }

    public void setSignSn(String signSn) {
        this.signSn = signSn;
    }

    public String getTempName() {
        return tempName;
    }

    public void setTempName(String tempName) {
        this.tempName = tempName;
    }

    public String getTempNo() {
        return tempNo;
    }

    public void setTempNo(String tempNo) {
        this.tempNo = tempNo;
    }

    public String getTempParas() {
        return tempParas;
    }

    public void setTempParas(String tempParas) {
        this.tempParas = tempParas;
    }

    @Override
    public String toString() {
        final StringBuilder sb = new StringBuilder("FreezeApplyInfo{");
        sb.append("applyReason='").append(applyReason).append('\'');
        sb.append(", applyStatus=").append(applyStatus);
        sb.append(", certDn='").append(certDn).append('\'');
        sb.append(", encSn='").append(encSn).append('\'');
        sb.append(", gmtCreate='").append(gmtCreate).append('\'');
        sb.append(", signSn='").append(signSn).append('\'');
        sb.append(", tempName='").append(tempName).append('\'');
        sb.append(", tempNo='").append(tempNo).append('\'');
        sb.append(", tempParas='").append(tempParas).append('\'');
        sb.append('}');
        return sb.toString();
    }
}

==> ra-sdk-2.0.0-sources.jar: com/xdja/ra/bean/FreezeApplyInfo.java <==
package com.xdja.ra.bean;

/**
 * 冻结/解冻申请详情
 *
 * @author yangmenghao
 * @date 2020-03-24 10:30:58
 */
public class FreezeApplyInfo {
    /**
     * 必须	申请原因
     */
    private String applyReason;
    /**
     * 必须	申请状态 1:待审核  2:审核未通过  3:待签发  4:签发未通过  5:已签发  6:撤销失败   7:已撤销  8:冻结失败 9:已冻结  10:解冻失败  11:已解冻
     */
    private Integer applyStatus;
    /**
     * 必须	待冻结/解冻证书DN
     */
    private String certDn;
    /**
     * 必须	待冻结/解冻证书的加密证书SN
     */
    private String encSn;
    /**
     * 必须	申请创建时间
     */
    private String gmtCreate;
    /**
     * 必须	待冻结/解冻证书的签名证书SN
     */
    private String signSn;
    /**
     * 必填	模板名称
     */
    private String tempName;
    /**
     * 必填	模板编号
     */
    private String tempNo;
    /**
     * 必填	模板要求参数
     */
    private String tempParas;
    /**
     * 所属用户CA
     */
    private String userCA;

    public String getUserCA() {
        return userCA;
    }

    public void setUserCA(String userCA) {
        this.userCA = userCA;
    }

    public String getApplyReason() {
        return applyReason;
    }

    public void setApplyReason(String applyReason) {
        this.applyReason = applyReason;
    }

    public Integer getApplyStatus() {
        return applyStatus;
    }

    public void setApplyStatus(Integer applyStatus) {
        this.applyStatus = applyStatus;
    }

    public String getCertDn() {
        return certDn;
    }

    public void setCertDn(String certDn) {
        this.certDn = certDn;
    }

    public String getEncSn() {
        return encSn;
    }

    public void setEncSn(String encSn) {
        this.encSn = encSn;
    }

    public String getGmtCreate() {
        return gmtCreate;
    }

    public void setGmtCreate(String gmtCreate) {
        this.gmtCreate = gmtCreate;
    }

    public String getSignSn() {
        return signSn;
    }

    public void setSignSn(String signSn) {
        this.signSn = signSn;
    }

    public String getTempName() {
        return tempName;
    }

    public void setTempName(String tempName) {
        this.tempName = tempName;
    }

    public String getTempNo() {
        return tempNo;
    }

    public void setTempNo(String tempNo) {
        this.tempNo = tempNo;
    }

    public String getTempParas() {
        return tempParas;
    }

    public void setTempParas(String tempParas) {
        this.tempParas = tempParas;
    }

    @Override
    public String toString() {
        final StringBuilder sb = new StringBuilder("FreezeApplyInfo{");
        sb.append("applyReason='").append(applyReason).append('\'');
        sb.append(", applyStatus=").append(applyStatus);
        sb.append(", certDn='").append(certDn).append('\'');
        sb.append(", encSn='").append(encSn).append('\'');
        sb.append(", gmtCreate='").append(gmtCreate).append('\'');
        sb.append(", signSn='").append(signSn).append('\'');
        sb.append(", tempName='").append(tempName).append('\'');
        sb.append(", tempNo='").append(tempNo).append('\'');
        sb.append(", tempParas='").append(tempParas).append('\'');
        sb.append(", userCA='").append(userCA).append('\'');
        sb.append('}');
        return sb.toString();
    }
}
